@@ -34,6 +34,9 @@ if t.TYPE_CHECKING or os.getenv("CG_EAGERIMPORT", False):
     from ..models.import_into_assignment_data import ImportIntoAssignmentData
     from ..models.job import Job
     from ..models.patch_assignment_data import PatchAssignmentData
+    from ..models.patch_rubric_category_type_assignment_data import (
+        PatchRubricCategoryTypeAssignmentData,
+    )
     from ..models.patch_submit_types_assignment_data import (
         PatchSubmitTypesAssignmentData,
     )
@@ -204,6 +207,65 @@ class AssignmentService(t.Generic[_ClientT]):
             ),
         )
 
+    def patch_rubric_category_type(
+        self: "AssignmentService[codegrade.client.AuthenticatedClient]",
+        json_body: t.Union[
+            dict, list, "PatchRubricCategoryTypeAssignmentData"
+        ],
+        *,
+        assignment_id: "int",
+        rubric_category_id: "int",
+        extra_parameters: t.Mapping[
+            str, t.Union[str, bool, int, float]
+        ] = None,
+    ) -> "RubricRowBase":
+        """Change the type of a rubric category.
+
+        :param json_body: The body of the request. See
+            :class:`.PatchRubricCategoryTypeAssignmentData` for information
+            about the possible fields. You can provide this data as a
+            :class:`.PatchRubricCategoryTypeAssignmentData` or as a dictionary.
+        :param assignment_id: The assignment of the rubric category.
+        :param rubric_category_id: The rubric category you want to change the
+            type of.
+        :param extra_parameters: The extra query parameters you might want to
+            add. By default no extra query parameters are added.
+
+        :returns: The updated rubric row.
+        """
+
+        url = "/api/v1/assignments/{assignmentId}/rubrics/{rubricCategoryId}/type".format(
+            assignmentId=assignment_id, rubricCategoryId=rubric_category_id
+        )
+        params = extra_parameters or {}
+
+        with self.__client as client:
+            resp = client.http.patch(
+                url=url, json=utils.to_dict(json_body), params=params
+            )
+        utils.log_warnings(resp)
+
+        if utils.response_code_matches(resp.status_code, 200):
+            # fmt: off
+            from ..models.rubric_row_base import RubricRowBase
+
+            # fmt: on
+            return parsers.JsonResponseParser(
+                parsers.ParserFor.make(RubricRowBase)
+            ).try_parse(resp)
+
+        from ..models.any_error import AnyError
+
+        raise utils.get_error(
+            resp,
+            (
+                (
+                    (400, 409, 401, 403, 404, "5XX"),
+                    utils.unpack_union(AnyError),
+                ),
+            ),
+        )
+
     def get(
         self: "AssignmentService[codegrade.client.AuthenticatedClient]",
         *,
