@@ -87,6 +87,10 @@ class AllSiteSettings(FrontendSiteSettings):
     max_user_setting_amount: "int"
     #: Should a registration email be sent to new users upon registration.
     send_registration_email: "bool"
+    #: Whether CodeGrade should try to automatically copy over assignment
+    #: settings when it is detected that the course of an assignment is copied
+    #: from another course within the same LTI provider.
+    automatic_lti_1p3_assignment_import: "bool"
 
     raw_data: t.Optional[t.Dict[str, t.Any]] = field(init=False, repr=False)
 
@@ -280,6 +284,16 @@ class AllSiteSettings(FrontendSiteSettings):
                         " registration."
                     ),
                 ),
+                rqa.RequiredArgument(
+                    "AUTOMATIC_LTI_1P3_ASSIGNMENT_IMPORT",
+                    rqa.SimpleValue.bool,
+                    doc=(
+                        "Whether CodeGrade should try to automatically copy"
+                        " over assignment settings when it is detected that"
+                        " the course of an assignment is copied from another"
+                        " course within the same LTI provider."
+                    ),
+                ),
             )
         ).use_readable_describe(True)
     )
@@ -320,6 +334,9 @@ class AllSiteSettings(FrontendSiteSettings):
             "MAX_MIRROR_FILE_AGE": to_dict(self.max_mirror_file_age),
             "MAX_USER_SETTING_AMOUNT": to_dict(self.max_user_setting_amount),
             "SEND_REGISTRATION_EMAIL": to_dict(self.send_registration_email),
+            "AUTOMATIC_LTI_1P3_ASSIGNMENT_IMPORT": to_dict(
+                self.automatic_lti_1p3_assignment_import
+            ),
             "AUTO_TEST_MAX_TIME_COMMAND": to_dict(
                 self.auto_test_max_time_command
             ),
@@ -414,6 +431,13 @@ class AllSiteSettings(FrontendSiteSettings):
             "SERVER_TIME_SYNC_INTERVAL": to_dict(
                 self.server_time_sync_interval
             ),
+            "IS_ADMIN_PERMISSION_ENABLED": to_dict(
+                self.is_admin_permission_enabled
+            ),
+            "TOUR_POLLING_INTERVAL": to_dict(self.tour_polling_interval),
+            "FIND_ELEMENT_INTERVAL": to_dict(self.find_element_interval),
+            "FIND_ELEMENT_MAX_TRIES": to_dict(self.find_element_max_tries),
+            "TOUR_CONFIGURATIONS": to_dict(self.tour_configurations),
         }
         return res
 
@@ -444,6 +468,7 @@ class AllSiteSettings(FrontendSiteSettings):
             max_mirror_file_age=parsed.MAX_MIRROR_FILE_AGE,
             max_user_setting_amount=parsed.MAX_USER_SETTING_AMOUNT,
             send_registration_email=parsed.SEND_REGISTRATION_EMAIL,
+            automatic_lti_1p3_assignment_import=parsed.AUTOMATIC_LTI_1P3_ASSIGNMENT_IMPORT,
             auto_test_max_time_command=parsed.AUTO_TEST_MAX_TIME_COMMAND,
             auto_test_io_test_message=parsed.AUTO_TEST_IO_TEST_MESSAGE,
             auto_test_io_test_sub_message=parsed.AUTO_TEST_IO_TEST_SUB_MESSAGE,
@@ -490,6 +515,11 @@ class AllSiteSettings(FrontendSiteSettings):
             metric_gathering_expressions=parsed.METRIC_GATHERING_EXPRESSIONS,
             server_time_diff_tolerance=parsed.SERVER_TIME_DIFF_TOLERANCE,
             server_time_sync_interval=parsed.SERVER_TIME_SYNC_INTERVAL,
+            is_admin_permission_enabled=parsed.IS_ADMIN_PERMISSION_ENABLED,
+            tour_polling_interval=parsed.TOUR_POLLING_INTERVAL,
+            find_element_interval=parsed.FIND_ELEMENT_INTERVAL,
+            find_element_max_tries=parsed.FIND_ELEMENT_MAX_TRIES,
+            tour_configurations=parsed.TOUR_CONFIGURATIONS,
         )
         res.raw_data = d
         return res
