@@ -146,6 +146,25 @@ class FrontendSiteSettings:
     #: The interval at which we request the server time in case it is out of
     #: sync with the local time.
     server_time_sync_interval: "datetime.timedelta"
+    #: Whether the is\_admin global permission should be enabled. Users with a
+    #: global role with this permission automatically get all permissions,
+    #: everywhere. Users with a tenant role with this permission automatically
+    #: get all permissions within their tenant.
+    is_admin_permission_enabled: "bool"
+    #: The interval of time in milliseconds between each search of the starting
+    #: element of a tour once the component trigger is found and visible.
+    tour_polling_interval: "int"
+    #: The interval of time in milliseconds between each search for the
+    #: anchoring elements of a tour step on the DOM.
+    find_element_interval: "int"
+    #: The maximum number of tries while searching for the anchoring elements
+    #: of a tour step on the DOM.
+    find_element_max_tries: "int"
+    #: Tour Configurations for enabled components. For each tour a name, a
+    #: component trigger, and a starting trigger need to be specified. Tour
+    #: Names must be unique, and each tour can contain an arbitrary number of
+    #: steps.
+    tour_configurations: "t.Sequence[t.Any]"
 
     raw_data: t.Optional[t.Dict[str, t.Any]] = field(init=False, repr=False)
 
@@ -485,6 +504,52 @@ class FrontendSiteSettings:
                     " it is out of sync with the local time."
                 ),
             ),
+            rqa.RequiredArgument(
+                "IS_ADMIN_PERMISSION_ENABLED",
+                rqa.SimpleValue.bool,
+                doc=(
+                    "Whether the is\\_admin global permission should be"
+                    " enabled. Users with a global role with this permission"
+                    " automatically get all permissions, everywhere. Users"
+                    " with a tenant role with this permission automatically"
+                    " get all permissions within their tenant."
+                ),
+            ),
+            rqa.RequiredArgument(
+                "TOUR_POLLING_INTERVAL",
+                rqa.SimpleValue.int,
+                doc=(
+                    "The interval of time in milliseconds between each search"
+                    " of the starting element of a tour once the component"
+                    " trigger is found and visible."
+                ),
+            ),
+            rqa.RequiredArgument(
+                "FIND_ELEMENT_INTERVAL",
+                rqa.SimpleValue.int,
+                doc=(
+                    "The interval of time in milliseconds between each search"
+                    " for the anchoring elements of a tour step on the DOM."
+                ),
+            ),
+            rqa.RequiredArgument(
+                "FIND_ELEMENT_MAX_TRIES",
+                rqa.SimpleValue.int,
+                doc=(
+                    "The maximum number of tries while searching for the"
+                    " anchoring elements of a tour step on the DOM."
+                ),
+            ),
+            rqa.RequiredArgument(
+                "TOUR_CONFIGURATIONS",
+                rqa.List(rqa.AnyValue),
+                doc=(
+                    "Tour Configurations for enabled components. For each tour"
+                    " a name, a component trigger, and a starting trigger need"
+                    " to be specified. Tour Names must be unique, and each"
+                    " tour can contain an arbitrary number of steps."
+                ),
+            ),
         ).use_readable_describe(True)
     )
 
@@ -584,6 +649,13 @@ class FrontendSiteSettings:
             "SERVER_TIME_SYNC_INTERVAL": to_dict(
                 self.server_time_sync_interval
             ),
+            "IS_ADMIN_PERMISSION_ENABLED": to_dict(
+                self.is_admin_permission_enabled
+            ),
+            "TOUR_POLLING_INTERVAL": to_dict(self.tour_polling_interval),
+            "FIND_ELEMENT_INTERVAL": to_dict(self.find_element_interval),
+            "FIND_ELEMENT_MAX_TRIES": to_dict(self.find_element_max_tries),
+            "TOUR_CONFIGURATIONS": to_dict(self.tour_configurations),
         }
         return res
 
@@ -640,6 +712,11 @@ class FrontendSiteSettings:
             metric_gathering_expressions=parsed.METRIC_GATHERING_EXPRESSIONS,
             server_time_diff_tolerance=parsed.SERVER_TIME_DIFF_TOLERANCE,
             server_time_sync_interval=parsed.SERVER_TIME_SYNC_INTERVAL,
+            is_admin_permission_enabled=parsed.IS_ADMIN_PERMISSION_ENABLED,
+            tour_polling_interval=parsed.TOUR_POLLING_INTERVAL,
+            find_element_interval=parsed.FIND_ELEMENT_INTERVAL,
+            find_element_max_tries=parsed.FIND_ELEMENT_MAX_TRIES,
+            tour_configurations=parsed.TOUR_CONFIGURATIONS,
         )
         res.raw_data = d
         return res
